diff --git a/test/cpp/qps/driver.cc b/test/cpp/qps/driver.cc
index 5be5f7986897eff2e947bb2f6b98b29383d48e9f..67bdcb2f32ca033b019a4671ca78c912cc7e9208 100644
--- a/test/cpp/qps/driver.cc
+++ b/test/cpp/qps/driver.cc
@@ -161,7 +161,7 @@ std::unique_ptr<ScenarioResult> RunScenario(
   // where class contained in std::vector must have a copy constructor
   auto* servers = new ServerData[num_servers];
   for (size_t i = 0; i < num_servers; i++) {
-    servers[i].stub = Worker::NewStub(
+    servers[i].stub = WorkerService::NewStub(
         CreateChannel(workers[i], InsecureChannelCredentials()));
     ServerArgs args;
     result_server_config = server_config;
@@ -188,7 +188,7 @@ std::unique_ptr<ScenarioResult> RunScenario(
   // where class contained in std::vector must have a copy constructor
   auto* clients = new ClientData[num_clients];
   for (size_t i = 0; i < num_clients; i++) {
-    clients[i].stub = Worker::NewStub(
+    clients[i].stub = WorkerService::NewStub(
         CreateChannel(workers[i + num_servers], InsecureChannelCredentials()));
     ClientArgs args;
     result_client_config = client_config;
diff --git a/test/cpp/interop/stress_interop_client.cc b/test/cpp/interop/stress_interop_client.cc
index f8c55cf795917023d42f01a2058b231a0374a503..3be2571493476b7cff0603ea894794b86fd21d45 100644
--- a/test/cpp/interop/stress_interop_client.cc
+++ b/test/cpp/interop/stress_interop_client.cc
@@ -89,9 +89,9 @@ StressTestInteropClient::StressTestInteropClient(
       test_duration_secs_(test_duration_secs),
       sleep_duration_ms_(sleep_duration_ms) {
   // TODO(sreek): This will change once we add support for other tests
   // that won't work with InsecureCredentials()
   std::shared_ptr<Channel> channel(
-      CreateChannel(server_address, InsecureCredentials()));
+      CreateChannel(server_address, InsecureChannelCredentials()));
   interop_client_.reset(new InteropClient(channel, false));
 }
 
@@ -89,9 +89,9 @@ StressTestInteropClient::StressTestInteropClient(
       sleep_duration_ms_(sleep_duration_ms) {
   // TODO(sreek): This will change once we add support for other tests
-  // that won't work with InsecureCredentials()
+  // that won't work with InsecureChannelCredentials()
   std::shared_ptr<Channel> channel(